Quick start guide — Django Grappelli 2.15.4 documentation

# Quick start guide

For using Grappelli 2.15.4, Django 3.2 needs to be installed and an Admin Site has to be activated.

## Installation

    $ pip install django-grappelli

Go to https://github.com/sehmaschine/django-grappelli if you need to download a package or clone/fork the repository.

## Setup

Open `settings.py` and add `grappelli` to your `INSTALLED_APPS` (before `django.contrib.admin`):

    INSTALLED_APPS = (
        'grappelli',
        'django.contrib.admin',
    )

Add URL-patterns. The grappelli URLs are needed for related–lookups and autocompletes. Your admin interface is available with the URL you defined for `admin.site`:

    from django.conf.urls import include

    urlpatterns = [
        path('grappelli/', include('grappelli.urls')), # grappelli URLS
        path('admin/', admin.site.urls), # admin site
    ]

Add the request context processor (needed for the Dashboard and the Switch User feature):

    TEMPLATES = [
        {
            ...
            'OPTIONS': {
                'context_processors': [
                    ...
                    'django.template.context_processors.request',
                    ...
                ],
            },
        },
    ]

Collect the media files:

    $ python manage.py collectstatic

## Testing

Start the devserver and login to your admin site:

    $ python manage.py runserver <IP-address>:8000

Check if everything looks/works as expected. If you’re having problems, see Troubleshooting.